==> nextcloud-29.0.14.tar.bz2: nextcloud/apps/activity/l10n/uk.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Особиста стрічка подій для %s",
    "Your feed URL is invalid" : "URL-адреса вашої стрічки недійсна",
    "Activity feed for %1$s" : "Стрічка подій для %1$s",
    "Activity feed" : "Стрічка дій",
    "Your settings have been updated." : "Налаштування успішно оновлено.",
    "Settings have been updated." : "Налаштування було оновлено.",
    "Recent activity" : "Нещодавна активність",
    "No activities" : "Активність відсутня",
    "More activities" : "Більше заходів",
    "Daily activity summary for %s" : "Підсумок за день для%s",
    "_and %n more…_::_and %n more…_" : ["та ще %n ..."," та ще %n ...","та ще %n ...","та ще %n ..."],
    "All activities" : "Всі події",
    "By others" : "Дії інших користувачів",
    "By you" : "Мої дії",
    "Activity at %s" : "Останні дії у %s",
    "Hello %s" : "Вітаємо %s",
    "Hello %s," : "Вітаємо %s,",
    "There was some activity at %s" : "Перелік останніх змін у %s",
    "_and %n more _::_and %n more _" : ["та ще %n","та ще %n","та ще %n","та ще %n "],
    "Mail" : "Пошта",
    "Push" : "Push",
    "Activity" : "Події",
    "Notifications" : "Сповіщення",
    "This application enables people to view a log of activities about them, their files or other data." : "За допомогою цього застосунку ви зможете переглядати журнал дій в системі, роботу з файлами та іншими даними.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Цей застосунок дозволяє людям переглядати дії, які повʼязані з їхніми файлами та даними в Nextcloud.\n\t\tКожна особа може обрати персональні налаштування,\n\t\tвибрати, які активності потрібно надсилати на смартфон чи електронною поштою\n\t\tабо надсилати щоденне ранкове зведення .\n\t\tДокладніше на сторінці документації \"Події\".",
    "Send email" : "Надіслати",
    "Send push notification" : "Надіслати push-повідомлення",
    "Activity notification configuration" : "Конфігурація сповіщень про дії",
    "Today" : "Сьогодні",
    "Yesterday" : "Вчора",
    "You need to set up your email address before you can receive notification emails." : "Для отримання повідомлень зазначте електронну адресу в особистих налаштуваннях.",
    "Send activity emails" : "Надсилати оновлення ел. поштою",
    "As soon as possible" : "Якнайшвидше",
    "Hourly" : "Щогодини",
    "Daily" : "Щоденно",
    "Weekly" : "Щотижня",
    "You commented" : "Ви прокоментували",
    "Message deleted by author" : "Автор вилучив повідомлення",
    "Open {filename}" : "Відкрити {filename}",
    "in {path}" : "в {path}",
    "Home" : "Домівка",
    "Could not load activities" : "Не вдалося завантажити дії",
    "Loading activities" : "Завантаження подій",
    "This stream will show events like additions, changes & shares" : "У цьому потоці буде показані події на кшталт доповнення, зміни та поширення",
    "No activity yet" : "Поки що відсутні події",
    "Loading more activities" : "Більше дій",
    "No more activities." : "Відсутні інші дії.",
    "Could not enable RSS link" : "Не вдалося увімкнути посилання на стрічку RSS",
    "RSS link copied to clipboard" : "Посилання на стрічку RSS скопійовано",
    "Could not copy the RSS link, please copy manually:" : "Не вдалося скопіювати посилання RSS. Скопіювати вручну:",
    "Activity settings" : "Налаштування",
    "Enable RSS feed" : "Увімкнути стрічку RSS",
    "RSS feed" : "Стрічка RSS",
    "Copy RSS feed link" : "Скопіювати посилання на RSS-стрічку",
    "Personal notification settings" : "Налаштування сповіщень",
    "Unable to load the activity list" : "Неможливо завантажити список дій",
    "Choose for which activities you want to get an email or push notification." : "Оберіть події щодо яких Ви бажаєте отримувати сповіщення електронною поштою або у вигляді push-сповіщень.",
    "Choose for which activities you want to get a push notification." : "Оберіть події щодо яких Ви бажаєте отримувати puch-сповіщеня.",
    "Notification" : "Сповіщення",
    "Enable notification emails" : "Надсилати сповіщення електронною поштою",
    "Daily activity summary" : "Щоденні підсумки про події",
    "Send daily activity summary in the morning" : "Надсилати вранці щоденні зведення",
    "Default settings" : "Типові налаштування",
    "Configure the default notification settings for new accounts." : "Налаштуйте типові налаштування сповіщення для нових облікових записів.",
    "Unable to save the settings" : "Не вдалося зберегти налаштування",
    "No more events to load" : "Відсутні події для завантаження"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");

==> nextcloud-31.0.14.tar.bz2: nextcloud/apps/activity/l10n/uk.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Особиста стрічка подій для %s",
    "Your feed URL is invalid" : "URL-адреса вашої стрічки недійсна",
    "Activity feed for %1$s" : "Стрічка подій для %1$s",
    "Activity feed" : "Стрічка дій",
    "Your settings have been updated." : "Налаштування успішно оновлено.",
    "Settings have been updated." : "Налаштування було оновлено.",
    "remote user" : "віддалений користувач",
    "Recent activity" : "Нещодавна активність",
    "No activities" : "Відсутні події",
    "More activities" : "Більше подій",
    "Daily activity summary for %s" : "Підсумок за день для%s",
    "_and %n more…_::_and %n more…_" : ["та ще %n ..."," та ще %n ...","та ще %n ...","та ще %n ..."],
    "You can disable daily digest emails in the <a href=\"%s\">settings</a>." : "Ви можете вимкнути щоденну розсилку ел. поштою у <a href=\"%s\">налаштуваннях</a>.",
    "You can disable daily digest emails in the settings: %s" : "Ви можете вимкнути щоденну розсилку ел. поштою у налаштуваннях: %s",
    "All activities" : "Всі події",
    "By others" : "Дії інших користувачів",
    "By you" : "Мої дії",
    "Activity at %s" : "Останні дії у %s",
    "Hello %s" : "Вітаємо %s",
    "Hello %s," : "Вітаємо %s,",
    "There was some activity at %s" : "Перелік останніх змін у %s",
    "_and %n more _::_and %n more _" : ["та ще %n","та ще %n","та ще %n","та ще %n "],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Ви можете змінити частоту отримання сповіщень ел.поштою або взагалі вимкнути отримання листів зі сповіщеннями у <a href=\"%s\">налаштуваннях</a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Ви можете змінити частоту отримання сповіщень на ел.пошту або взагалі вимкнути отримання листів зі сповіщеннями у налаштуваннях: %s",
    "Mail" : "Пошта",
    "Push" : "Push",
    "Activity" : "Події",
    "Notifications" : "Сповіщення",
    "This application enables people to view a log of activities about them, their files or other data." : "За допомогою цього застосунку ви зможете переглядати журнал подій в системі, роботу з файлами та іншими даними.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Цей застосунок дозволяє людям переглядати дії, які повʼязані з їхніми файлами та даними в Nextcloud.\n\t\tКожна особа може обрати персональні налаштування,\n\t\tвибрати, які активності потрібно надсилати на смартфон чи електронною поштою\n\t\tабо надсилати щоденне ранкове зведення .\n\t\tДокладніше на сторінці документації \"Події\".",
    "Send email" : "Надіслати",
    "Send push notification" : "Надіслати push-повідомлення",
    "Activity notification configuration" : "Конфігурація сповіщень про дії",
    "Today" : "Сьогодні",
    "Yesterday" : "Вчора",
    "You need to set up your email address before you can receive notification emails." : "Для отримання повідомлень зазначте електронну адресу в особистих налаштуваннях.",
    "Send activity emails" : "Надсилати оновлення ел. поштою",
    "As soon as possible" : "Якнайшвидше",
    "Hourly" : "Щогодини",
    "Daily" : "Щоденно",
    "Weekly" : "Щотижня",
    "You commented" : "Ви прокоментували",
    "Message deleted by author" : "Автор вилучив повідомлення",
    "Open {filename}" : "Відкрити {filename}",
    "in {path}" : "в {path}",
    "Home" : "Домівка",
    "Could not load activities" : "Не вдалося завантажити події",
    "Loading activities" : "Завантаження подій",
    "This stream will show events like additions, changes & shares" : "У цьому потоці буде показані події на кшталт доповнення, зміни та поширення",
    "No activity yet" : "Поки що відсутні події",
    "Loading more activities" : "Більше подій",
    "No more activities." : "Відсутні інші події.",
    "Could not enable RSS link" : "Не вдалося увімкнути посилання на стрічку RSS",
    "RSS link copied to clipboard" : "Посилання на стрічку RSS скопійовано",
    "Could not copy the RSS link, please copy manually:" : "Не вдалося скопіювати посилання RSS. Скопіювати вручну:",
    "Activity settings" : "Налаштування",
    "Enable RSS feed" : "Увімкнути стрічку RSS",
    "RSS feed" : "Стрічка RSS",
    "Copy RSS feed link" : "Скопіювати посилання на RSS-стрічку",
    "Personal notification settings" : "Налаштування",
    "Unable to load the activity list" : "Неможливо завантажити список дій",
    "Choose for which activities you want to get an email or push notification." : "Оберіть події щодо яких Ви бажаєте отримувати сповіщення електронною поштою або у вигляді push-сповіщень.",
    "Choose for which activities you want to get a push notification." : "Оберіть події щодо яких Ви бажаєте отримувати puch-сповіщеня.",
    "Notification" : "Сповіщення",
    "Enable notification emails" : "Надсилати сповіщення електронною поштою",
    "Daily activity summary" : "Щоденні підсумки про події",
    "Send daily activity summary in the morning" : "Надсилати вранці щоденні зведення",
    "Default settings" : "Типові налаштування",
    "Configure the default notification settings for new accounts." : "Налаштуйте типові налаштування сповіщення для нових облікових записів.",
    "Unable to save the settings" : "Не вдалося зберегти налаштування",
    "No more events to load" : "Відсутні події для завантаження"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
